@@ -1,4 +1,4 @@
-GOF_model_resample_works <- function() {
+GOF_model_resample_works <- function() { # nolint
   d <- data.frame(y = 101:110, x = 1:10)
   ms_mock <- R6::R6Class(
     inherit = GOF_model_simulator,
@@ -7,7 +7,10 @@ GOF_model_resample_works <- function() {
         1:10
       }))$new()
   mt <- GOF_lm_trainer$new()
-  mr <- GOF_model_resample$new(gof_model_simulator = ms_mock, gof_model_trainer = mt)
+  mr <- GOF_model_resample$new(
+    gof_model_simulator = ms_mock,
+    gof_model_trainer = mt
+  )
   fit <- lm(y~x, data = d)
   fit_new <- mr$resample(model = fit, data = d, y_name = "y")
   expect_equivalent(
